package logic

import (
	"GtDataStore/app/cmd/organization/internal/svc"
	"GtDataStore/app/cmd/organization/pb"
	"GtDataStore/app/model"
	"context"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetWorkingChestByCodeLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetWorkingChestByCodeLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetWorkingChestByCodeLogic {
	return &GetWorkingChestByCodeLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetWorkingChestByCodeLogic) GetWorkingChestByCode(in *pb.DcWorkingReq) (*pb.GetWorkingChestByCodeResp, error) {
	offset := (in.Page - 1) * in.PageSize
	res, err := l.svcCtx.WorkingChest.Search(l.ctx, in.ProjectId, in.DeviceCode, in.Stime, in.Etime, offset, in.PageSize, in.Order)
	if err != nil && err != model.ErrNotFound {
		return nil, err
	}

	list := make([]*pb.WorkingChest, len(res))
	for i, one := range res {
		list[i] = &pb.WorkingChest{
			Id:                  one.Id,
			ProjectId:           one.ProjectId,
			DeviceCode:          one.DeviceCode,
			Switch:              one.Switch,
			Level:               one.Level,
			AgitatorStatus:      one.AgitatorStatus,
			AgitatorDuration:    one.AgitatorDuration,
			AgitatorFaultStatus: one.AgitatorFaultStatus,
			CTime:               one.CTime.Format("2006-01-02 15:04:05"),
		}
	}

	return &pb.GetWorkingChestByCodeResp{
		List: list,
	}, nil
}
